Learn R Programming

VLMC (version 1.4-1)

alphabet: The Alphabet in Use

Description

Return the alphabet in use, as a vector of “characters”.

Usage

alphabet(x, …)
# S3 method for vlmc
alphabet(x, …)

Arguments

x

any R object, currently only available for vlmc ones.

potential further arguments passed to and from methods.

Value

a character vector, say r, with length equal to the alphabet size. Currently, typically all r[i] are strings of just one character.

See Also

alpha2int for conversion to and from integer codings.

Examples

Run this code
# NOT RUN {
data(bnrf1)
vb <- vlmc(bnrf1EB, cutoff = 5)
alphabet(vb) # |--> "a" "c" "g" "t"
# }

Run the code above in your browser using DataLab