powered by
Return the alphabet in use, as a vector of “characters”.
alphabet(x, …) # S3 method for vlmc alphabet(x, …)
any R object, currently only available for vlmc ones.
vlmc
potential further arguments passed to and from methods.
a character vector, say r, with length equal to the alphabet size. Currently, typically all r[i] are strings of just one character.
character
r
r[i]
alpha2int for conversion to and from integer codings.
alpha2int
# NOT RUN { data(bnrf1) vb <- vlmc(bnrf1EB, cutoff = 5) alphabet(vb) # |--> "a" "c" "g" "t" # }
Run the code above in your browser using DataLab